@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants import paths
+from hdsr_wis_config_reader import constants
 from hdsr_wis_config_reader.tests.fixtures import loc_sets
 
 import pandas as pd  # noqa pandas comes with geopandas
@@ -146,7 +146,7 @@ expected_attrib_files = [
 
 
 def test_hoofdlocationset(loc_sets):
-    assert loc_sets.hoofdloc.fews_config.path == paths.WIS_CONFIG_TEST_DIR
+    assert loc_sets.hoofdloc.fews_config.path == constants.WIS_CONFIG_TEST_DIR
     assert loc_sets.hoofdloc.idmap_section_name == expected_idmap_section_name
     assert loc_sets.hoofdloc.name == expected_name
     assert loc_sets.hoofdloc.csv_filename == expected_csvfile
@@ -158,3 +158,11 @@ def test_hoofdlocationset(loc_sets):
     assert isinstance(loc_sets.hoofdloc.geo_df, pd.DataFrame)
     assert isinstance(loc_sets.hoofdloc.geo_df_original, pd.DataFrame)
     pd.testing.assert_frame_equal(left=loc_sets.hoofdloc.geo_df, right=loc_sets.hoofdloc.geo_df_original)
+
+
+def test_hoofdlocs_geom_z_nodata(loc_sets):
+    # we do not add '-9999' to location csv (as it becomes '-9999.0' since float column, better leave it blank)
+    assert loc_sets.hoofdloc.geo_df.iloc[0].Z == "2.87"
+    assert loc_sets.hoofdloc.geo_df.iloc[0].geometry.z == 2.87
+    assert loc_sets.hoofdloc.geo_df.iloc[1].Z == "", "empty cells should be left empty, so '' in csv and pd.NA in df"
+    assert loc_sets.hoofdloc.geo_df.iloc[1].geometry.z == loc_sets.hoofdloc.fews_config.Z_NODATA_VALUE
