@@ -1,4 +1,4 @@
-from hdsr_wis_config_reader.constants.location_sets.base import LocationSetBase
+from hdsr_wis_config_reader.location_sets.base import LocationSetBase
 from hdsr_wis_config_reader.tests.fixtures import loc_sets
 from typing import Dict
 from typing import List
